import { __decorate } from "tslib";
import { customElement, FASTElement, html, observable, ref } from '@microsoft/fast-element';
import { TestChannel } from './config';
/**
 * @internal
 */
let SubscriberTestElement = class SubscriberTestElement extends FASTElement {
    /**
     * @public
     */
    connectedCallback() {
        super.connectedCallback();
        this.channel.onmessage = (ev) => {
            if (this.channel.isMessageType('loaded', ev)) {
                const entities = ev.data.detail;
                if (!entities.length) {
                    throw Error('No test entities available');
                }
                this.entities = entities;
                return;
            }
            if (this.channel.isMessageType('unloaded', ev)) {
                this.entities = undefined;
            }
        };
    }
    /**
     * @public
     */
    disconnectedCallback() {
        super.disconnectedCallback();
        this.channel.close();
    }
};
__decorate([
    TestChannel
], SubscriberTestElement.prototype, "channel", void 0);
__decorate([
    observable
], SubscriberTestElement.prototype, "entities", void 0);
SubscriberTestElement = __decorate([
    customElement({
        name: 'subscriber-test-element',
        template: html `
    <template></template>
  `,
    })
], SubscriberTestElement);
export { SubscriberTestElement };
/**
 * @internal
 */
let BroadcasterTestElement = class BroadcasterTestElement extends FASTElement {
    /**
     * @public
     */
    postLoadedMessage(detail) {
        this.channel.postMessage('loaded', detail);
    }
    /**
     * @public
     */
    postUnloadedMessage() {
        this.channel.postMessage('unloaded');
    }
    /**
     * @public
     */
    disconnectedCallback() {
        super.disconnectedCallback();
        this.channel.close();
    }
};
__decorate([
    TestChannel
], BroadcasterTestElement.prototype, "channel", void 0);
BroadcasterTestElement = __decorate([
    customElement({
        name: 'broadcaster-test-element',
        template: html `
    <template></template>
  `,
    })
], BroadcasterTestElement);
export { BroadcasterTestElement };
/**
 * @internal
 */
let TestElement = class TestElement extends FASTElement {
};
__decorate([
    observable
], TestElement.prototype, "broadcaster", void 0);
__decorate([
    observable
], TestElement.prototype, "subscriber", void 0);
TestElement = __decorate([
    customElement({
        name: 'broadcast-channel-test-element',
        template: html `
    <template>
      <broadcaster-test-element ${ref('broadcaster')}></broadcaster-test-element>
      <subscriber-test-element ${ref('subscriber')}></subscriber-test-element>
    </template>
  `,
    })
], TestElement);
export { TestElement };
